@@ -23,20 +23,13 @@ class Play:
         self.app = settings.app
         self.rep = rep
         self.game: Game = rep.game
-
         self.exit = False
 
         self.flagsman = FlagsMan(self.rep.get_flags())
         self.fman = FloatingManager()
         self.tree = TaskTree(self.settings, rep, self.fman)
         self.gui = Gui(tree=self.tree, flagsman=self.flagsman, fman=self.fman)
-
-        # if len(self.rep.get_tasks()) == 0:
-        #     self.gui.show_help()
-
-        self.first_loop = True
-        self.graph_ext = ""
-
+        Flags.xray.set_value("0")
         self.actions = PlayActions(self.gui)
         self.play_palette = PlayConfig(self.actions)
 
@@ -54,7 +47,7 @@ class Play:
             self.exit = True
 
         self.fman.add_input(
-            Floating(self.settings).put_text("\nAté a próxima\n").set_exit_fn(set_exit).warning()
+            Floating(self.settings).put_text("\nAté a próxima\n").set_exit_fn(set_exit).set_warning()
         )
 
     def make_callback(self) -> InputManager:
@@ -62,34 +55,12 @@ class Play:
 
         cman.add_str(GuiKeys.key_quit, self.send_quit_msg)
         cman.add_int(InputManager.esc, self.send_quit_msg)
-        # cman.add_int(curses.KEY_BACKSPACE, self.send_quit_msg)
-
-        cman.add_str(GuiKeys.up, self.tree.move_up)
-        cman.add_str(GuiKeys.up2, self.tree.move_up)
-        key_up = self.app.get_key_up()
-        if key_up != 0:
-            cman.add_int(key_up, self.tree.move_up)
-
-        cman.add_str(GuiKeys.down, self.tree.move_down)
-        cman.add_str(GuiKeys.down2, self.tree.move_down)
-        key_down = self.app.get_key_down()
-        if key_down != 0:
-            cman.add_int(key_down, self.tree.move_down)
-
-        cman.add_str(GuiKeys.left, self.tree.arrow_left)
-        cman.add_str(GuiKeys.left2, self.tree.arrow_left)
-        key_left = self.app.get_key_left()
-        if key_left != 0:
-            cman.add_int(key_left, self.tree.arrow_left)
-
-        cman.add_str(GuiKeys.right, self.tree.arrow_right)
-        cman.add_str(GuiKeys.right2, self.tree.arrow_right)
-        key_right = self.app.get_key_right()
-        if key_right != 0:
-            cman.add_int(key_right, self.tree.arrow_right)
+        cman.add_int(curses.KEY_UP, self.tree.move_up)
+        cman.add_int(curses.KEY_DOWN, self.tree.move_down)
+        cman.add_int(curses.KEY_LEFT, self.tree.arrow_left)
+        cman.add_int(curses.KEY_RIGHT, self.tree.arrow_right)
 
         cman.add_str(GuiKeys.calibrate, lambda: self.fman.add_input(FloatingCalibrate(self.settings)))
-        
         cman.add_str(GuiKeys.activate, lambda: self.actions.select_task()) # type: ignore
         cman.add_str(GuiKeys.open_url, self.actions.open_link)
         cman.add_str(GuiKeys.down_task, self.actions.down_remote_task)
@@ -98,15 +69,13 @@ class Play:
         cman.add_str(GuiKeys.collapse, self.tree.process_collapse_all)
         cman.add_str(GuiKeys.borders, self.app.toggle_borders)
         cman.add_str(GuiKeys.images, self.app.toggle_images)
-        cman.add_str(GuiKeys.hidden, self.app.toggle_hidden)
         cman.add_str(GuiKeys.set_lang_drafts, self.gui.language.set_language)
-        cman.add_int(curses.KEY_BACKSPACE, self.actions.evaluate)
         cman.add_str(GuiKeys.grade_play, self.actions.evaluate)
-    
+        cman.add_str(GuiKeys.grade_play2, self.actions.evaluate)
         cman.add_str(GuiKeys.key_help, self.gui.show_help)
         
         for flag in self.flagsman.flags.values():
-            cman.add_str(flag.get_keycode(), FlagFunctor(flag))
+            cman.add_str(flag.get_keycode(), FlagFunctor(flag, self.fman, self.settings))
 
         cman.add_str(GuiKeys.search, self.gui.search.toggle_search)
         cman.add_str(GuiKeys.palette, self.play_palette.command_pallete)
@@ -114,13 +83,13 @@ class Play:
         return cman
         
     def send_char_not_found(self, key: int):
-        exclude_str = [ord(v) for v in [" ", "a", "d", "\n", GuiKeys.up, GuiKeys.down, GuiKeys.left, GuiKeys.right]]
-        exclude_int = [ -1, InputManager.esc] + InputManager.backspace_list
+        exclude_str = [ord(v) for v in [" ", "a", "d", "\n"]]
+        exclude_int = [ -1, InputManager.esc, curses.KEY_UP, curses.KEY_DOWN, curses.KEY_LEFT, curses.KEY_RIGHT] + InputManager.backspace_list
         if key in exclude_int + exclude_str:
             return
         if key < 0 or key > 255:
             return
-        self.fman.add_input( Floating(self.settings, "v>").error().put_text(f"Tecla char:{chr(key)}, code:{key}, não reconhecida") )
+        self.fman.add_input( Floating(self.settings, "v>").set_error().put_text(f"Tecla char:{chr(key)}, code:{key}, não reconhecida") )
 
 
     def main(self, scr: curses.window):
@@ -130,17 +99,21 @@ class Play:
         Fmt.set_scr(scr)  # Define o scr como global
 
         while True:
-            self.tree.update_tree(admin_mode=Flags.admin.is_true() or self.gui.search.search_mode)
+            self.tree.update_tree(admin_mode=Flags.quests.get_value() == "2" or self.gui.search.search_mode)
             self.fman.draw_warnings()
             cman = self.make_callback()
             self.gui.show_items()
 
             if self.fman.has_floating():
-                value: int = self.fman.get_input()
-            else:
-                value = scr.getch()
-                value = InputManager.fix_cedilha(scr, value)
+                self.fman.draw()
 
+            # o input tem que ser depois do draw para mostrar o floating
+            value = InputManager.get_and_remap_keys(scr, self.app)
+            
+            if self.fman.has_floating():
+                # if consumed, value becomes -1
+                value = self.fman.process_input(value)
+                
             if self.exit:
                 break
 
@@ -155,8 +128,6 @@ class Play:
 
             self.tree.reload_sentences()
             self.save_to_json()
-            if self.first_loop:
-                self.first_loop = False
 
     def check_lang_in_text_mode(self):
         lang = self.rep.get_lang()
