@@ -12,7 +12,7 @@ from tko.cmds.cmd_run import Run
 
 from tko.util.param import Param
 
-from tko.cmds.cmd_down import DownProblem
+from tko.cmds.cmd_down import DownActions
 
 from tko.play.fmt import Fmt
 from tko.play.floating import Floating
@@ -26,6 +26,7 @@ from tko.logger.log_item_self import LogItemSelf
 from tko.logger.log_item_move import LogItemMove
 
 import os
+import shutil
 import tempfile
 import subprocess
 
@@ -42,8 +43,6 @@ class PlayActions:
         self.graph_opened: bool = False
         self.gui = gui
 
-    def gen_graph_path(self) -> str:
-        return os.path.join(self.rep.paths.get_rep_dir(), "graph.png")
         
     @staticmethod
     def open_link_without_stdout_stderr(link: str):
@@ -56,6 +55,38 @@ class PlayActions:
             raise Exception("Folder não encontrado")
         return task.folder
 
+    def delete_folder(self):
+        obj = self.tree.get_selected_throw()
+        if isinstance(obj, Task):
+            task: Task = obj
+            folder = self.get_task_folder(task)
+            if os.path.exists(folder):
+                try:
+                    shutil.rmtree(folder)
+                    self.fman.add_input(
+                        Floating(self.settings, "v>")
+                        .put_text(f"\nPasta {folder} apagada com sucesso.\n")
+                        .set_warning()
+                    )
+                except OSError as e:
+                    self.fman.add_input(
+                        Floating(self.settings, "v>")
+                        .put_text(f"\nErro ao apagar a pasta {folder}: {e}\n")
+                        .set_error()
+                    )
+            else:
+                self.fman.add_input(
+                    Floating(self.settings, "v>")
+                    .put_text("\nPasta não encontrada.\n")
+                    .set_error()
+                )
+        else:
+            self.fman.add_input(
+                Floating(self.settings, "v>")
+                .put_text("\nVocê só pode apagar pastas de tarefas.\n")
+                .set_error()
+            )
+
     def open_code(self):
         obj = self.tree.get_selected_throw()
         if isinstance(obj, Task):
@@ -69,14 +100,14 @@ class PlayActions:
                 self.fman.add_input(
                     Floating(self.settings, "v>")
                     .put_text("\nO arquivo de código não foi encontrado.\n")
-                    .error()
+                    .set_error()
                 )
         else:
             self.fman.add_input(
                 Floating(self.settings, "v>")
                 .put_text("\nVocê só pode abrir o código")
                 .put_text("de tarefas baixadas.\n")
-                .error()
+                .set_error()
             )
 
     def open_link(self):
@@ -92,7 +123,7 @@ class PlayActions:
                 Floating(self.settings, "v>")
                 .set_header(" Abrindo link ")
                 .put_text("\n " + task.link + " \n")
-                .warning()
+                .set_warning()
             )
         elif isinstance(obj, Quest):
             self.fman.add_input(
@@ -100,7 +131,7 @@ class PlayActions:
                 .put_text("\nEssa é uma missão.")
                 .put_text("\nVocê só pode abrir o link")
                 .put_text("de tarefas.\n")
-                .error()
+                .set_error()
             )
         else:
             self.fman.add_input(
@@ -108,17 +139,9 @@ class PlayActions:
                 .put_text("\nEsse é um grupo.")
                 .put_text("\nVocê só pode abrir o link")
                 .put_text("de tarefas.\n")
-                .error()
+                .set_error()
             )
 
-    # def generate_graph(self):
-    #     Graph(self.game).set_path(self.gen_graph_path()).set_opt(False).generate()
-    #     path = self.gen_graph_path()
-    #     if not self.graph_opened:
-    #         opener = Opener(self.settings)
-    #         opener.open_files([path])
-    #         self.graph_opened = True
-
     def register_action(self, task: Task):
         self.rep.logger.store( LogItemSelf().set_key(task.key).set_info(task.info) )
 
@@ -148,7 +171,7 @@ class PlayActions:
                 Floating(self.settings, "v>")
                 .put_text("\nEssa é uma missão.")
                 .put_text("\nVocê só pode baixar tarefas.\n")
-                .error()
+                .set_error()
             )
             return
         if isinstance(obj, Cluster):
@@ -156,7 +179,7 @@ class PlayActions:
                 Floating(self.settings, "v>")
                 .put_text("\nEsse é um grupo.")
                 .put_text("\nVocê só pode baixar tarefas.\n")
-                .error()
+                .set_error()
             )
         if not isinstance(obj, Task):
             return
@@ -165,12 +188,12 @@ class PlayActions:
     def __down_remote_task(self, task: Task) -> None:
         if task.link_type != Task.Types.REMOTE_FILE and task.link_type != Task.Types.IMPORT_FILE:
             self.fman.add_input(
-                Floating(self.settings, "v>").put_text("\nEssa não é uma tarefa de baixável.\n").error()
+                Floating(self.settings, "v>").put_text("\nEssa não é uma tarefa de baixável.\n").set_error()
             )
             return
         lang = self.rep.get_lang() 
         down_frame = (
-            Floating(self.settings, "v>").warning().set_text_ljust().set_header(" Baixando tarefa ")
+            Floating(self.settings, "v>").set_warning().set_text_ljust().set_header(" Baixando tarefa ")
         )
         # down_frame.put_text(f"\ntko down {self.rep.alias} {task.key} -l {lang}\n")
         self.fman.add_input(down_frame)
@@ -226,13 +249,14 @@ class PlayActions:
         run.set_run_without_ask(False)
         run.set_curses(True)
         run.set_task(self.rep, task)
-
         run.build_wdir()
         
         if not run.wdir.has_solver():
-            DownProblem.create_default_draft(task_dir, self.rep.get_lang())
-            msg = Floating(self.settings, "v>").warning()
+            lang = self.rep.get_lang()
+            draft_folder = os.path.join(folder, lang)
+            DownActions().create_default_draft(draft_folder, self.rep.get_lang())
+            msg = Floating(self.settings, "v>").set_warning()
             msg.put_text("\nNenhum arquivo de código na linguagem {} encontrado.".format(self.rep.get_lang()))
-            msg.put_text("\nUm arquivo de rascunho foi criado em {}.".format(task_dir))
+            msg.put_text("\nUm arquivo de rascunho vazio foi criado em {}.".format(draft_folder))
             self.fman.add_input(msg)
         run.execute()
\ No newline at end of file
