@@ -39,7 +39,7 @@ class TaskTree:
         self.expanded: list[str] = []
         self.load_all_items()
         self.load_from_rep()
-        self.update_tree(admin_mode = Flags.admin.is_true())
+        self.update_tree(admin_mode = Flags.quests.get_value() == "2")
         self.reload_sentences()
 
     def load_all_items(self):
@@ -51,15 +51,9 @@ class TaskTree:
                     self.all_items[t.key] = t
 
     def load_from_rep(self):
-        # self.new_items: list[str] = [v for v in self.rep.get_new_items()]
         self.expanded: list[str] = [v for v in self.rep.get_expanded()]
         self.selected_item = self.rep.get_selected()
 
-        # tasks = self.rep.get_tasks()
-        # for key, serial in tasks.items():
-        #     if key in self.game.tasks:
-        #         self.game.tasks[key].load_from_db(serial)
-
     def save_on_rep(self):
         self.rep.set_expanded(self.expanded)
         # self.rep.set_new_items([x for x in set(self.new_items)])
@@ -71,27 +65,13 @@ class TaskTree:
         self.rep.set_tasks(tasks)
 
     def update_tree(self, admin_mode: bool):
-        #if not admin_mode:
-            # reachable_clusters = [c.key for c in self.game.clusters.values() if c.is_reachable()]
-            # reachable_quests = [q.key for q in self.game.quests.values() if q.is_reachable()]
-            # old_reachable = reachable_clusters + reachable_quests
-
         self.game.update_reachable_and_available()
-            
         if not admin_mode:
-            # reachable_clusters = [c.key for c in self.game.clusters.values() if c.is_reachable()]
             reachable_quests = [q.key for q in self.game.quests.values() if q.is_reachable()]
             reachable_keys = reachable_quests + list(self.game.clusters.keys())
             for key in self.expanded:
                 if key not in reachable_keys:
                     self.expanded.remove(key)
-            # if not first_loop:
-            #     for key in reachable_keys:
-            #         if key not in old_reachable and key not in self.new_items:
-            #             self.new_items.append(key)
-
-        # remove expanded items from new
-        # self.new_items = [item for item in self.new_items if item not in self.expanded]
 
     def __update_max_title(self):
         min_value = 50
@@ -104,7 +84,8 @@ class TaskTree:
                         items.append(len(q.get_full_title()) + 2)
                         if q.key in self.expanded:
                             for t in q.get_tasks():
-                                items.append(len(t.title) + 6)
+                                extra = 0 if not Flags.xray.is_true() else 6
+                                items.append(len(t.title) + extra + 9)
 
         self.max_title = min_value
         if len(items) > 0:
@@ -123,14 +104,14 @@ class TaskTree:
             if self.is_downloaded_for_lang(t):
                 down_symbol = symbols.task_downloaded
     
-        color_aval = "g" if quest_reachable and t.is_reachable() else "r"
+        color_aval = "g" if quest_reachable and t.is_reachable() else "y"
         color_lig_task = color_aval
-        if self.app.get_show_hidden() == False and not Flags.admin:
+        if Flags.quests.get_value() == "0":
             quest = self.game.quests[t.quest_key]
             if quest.prog:
                 if t.key != self.game.quests[t.quest_key].get_tasks()[-1].key:
                     if t.get_percent() < 50:
-                        color_lig_task = "y"
+                        color_lig_task = "r"
                     
 
         output = Text()
@@ -138,10 +119,14 @@ class TaskTree:
         output.add(" ")
         output.addf(color_lig_task, lig_quest)
         output.add(down_symbol).add(" ")
-        output.add(t.get_prog_symbol()).add(" ")
-        output.add(symbols.flow_list[t.info.flow]).add(" ")
-        output.add(symbols.edge_list[t.info.edge])
-
+        rate = t.info.rate // 10
+        output.add(t.get_prog_symbol(rate)).add(" ")
+        alone = t.info.alone
+        output.add(t.get_prog_symbol(alone)).add(" ")
+        output.addf("g" if t.info.human else "", "H")
+        output.addf("g" if t.info.iagen else "", "I")
+        output.addf("g" if t.info.guide else "", "G")
+        output.addf("g" if t.info.other else "", "O")
 
         if in_focus:
             output.add(self.style.round_l(focus_color))
@@ -164,39 +149,34 @@ class TaskTree:
             else:
                 output.addf(color, word + " ")
 
+        if Flags.xray.is_true():
+            logsort = self.rep.logger.tasks.task_dict.get(t.key, None)
+            if logsort is not None:
+                if len(logsort.base_list) > 0:
+                    delta, _ = logsort.base_list[-1]
+                    output.addf(focus_color + "y", f" {delta.accumulated.seconds // 60}min")
+
+
         if in_focus:
             output.add(self.style.round_r(focus_color))
         else:
             output.add(" ")
 
-        output.ljust(self.max_title + 10, Text.Token(" "))
-        # if Flags.percent.is_true():
+        output.ljust(self.max_title + 9, Text.Token(" "))
         prog = round(t.get_percent())
         output.addf("y", str(prog).rjust(3, " ") + "%")
-        # else:
-        #     color_rate: list[str] = ["", "c", "g", "y", "m", "r"]
-        #     rate = (t.info.neat + t.info.cool) / 2
-        #     for i in range(1, 6):
-        #         if rate >= i:
-        #             output.addf(color_rate[t.info.easy], symbols.star)
-        #         else:
-        #             output.addf(color_rate[t.info.easy], symbols.open_star)
-
-        # if Flags.reward:
-        #     xp = ""
-        #     for s, v in t.skills.items():
-        #         xp += f" +{s}:{v}"
-        #     output.addf(self.colors.task_skills, xp)
-            
         return output
 
     def __str_quest(self, has_kids: bool, focus_color: str, q: Quest, lig: str) -> Text:
-        con = "━─"
-        if q.key in self.expanded and has_kids:
-            con = "─┯"
+        con = "┄┄"
+        n_visible, n_hidden = self.count_visible_hidden_tasks(q)
+        if n_visible > 0:
+            con = "━─" if n_hidden == 0 else "━┄"
+            if q.key in self.expanded and has_kids:
+                con = "─╮" if n_hidden == 0 else "┄╮"
 
         color_reachable = "g" if q.is_reachable() else "r"
-        if self.app.get_show_hidden() == False and not Flags.admin:
+        if Flags.quests.get_value() == "2":
             for quest in self.game.quests.values():
                 if not quest.is_reachable():
                     if q.key in quest.requires:
@@ -214,18 +194,12 @@ class TaskTree:
                 if not quest.is_reachable():
                     if q.key in quest.requires:
                         focus_color = "y"
-                # elif quest.key in q.requires:
-                #     focus_color = "r"
 
         if in_focus:
             output.add(self.style.round_l(focus_color))
         else:
             output.add(" ")
 
-        # color = ""
-        # if in_focus:
-        #     color = "k" + focus_color
-
         title = q.get_full_title()
         title = title.ljust(self.max_title + 3, Text.Token("."))
         if focus_color != "":
@@ -238,8 +212,8 @@ class TaskTree:
         else:
             output.add(" ")
 
-        # if Flags.percent:
-        output.add(" ").add(q.get_resume_by_percent())
+        output.add(q.get_resume_by_percent())
+
         all_tasks_done = True
         for t in q.get_tasks():
             if not t.is_complete():
@@ -248,18 +222,6 @@ class TaskTree:
         if all_tasks_done:
             output.add("🌟")
 
-        # if Flags.minimum:
-        #     output.add(" ").add(q.get_requirement())
-
-        # if Flags.reward:
-        #     xp = ""
-        #     for s, v in q.skills.items():
-        #         xp += f" +{s}:{v}"
-        #     output.addf(self.colors.task_skills, xp)
-
-        # if q.key in self.new_items:
-        #     output.addf(self.colors.task_new, " [new]")
-
         return output
 
     def __str_cluster(self, has_kids: bool, focus_color: str, cluster: Cluster) -> Text:
@@ -267,7 +229,7 @@ class TaskTree:
         opening = "━─"
         if cluster.key in self.expanded and has_kids:
             opening = "─┯"
-        color_reachable = "g" if cluster.is_reachable() else "r"
+        color_reachable = "g" if cluster.is_reachable() else "y"
         output.addf(color_reachable, opening)
 
         color = ""
@@ -287,13 +249,8 @@ class TaskTree:
         else:
             output.add(" ")
 
+        output.add(cluster.get_resume_by_percent())
 
-        # if Flags.percent:
-        output.add(" ").add(cluster.get_resume_by_percent())
-        # else:
-        #     output.add(" ").add(cluster.get_resume_by_quests())
-        # if cluster.key in self.new_items:
-        #     output.addf(self.colors.task_new, " [new]")
 
         return output
 
@@ -342,14 +299,32 @@ class TaskTree:
             return True
         return False
 
+    def is_hide_tasks(self, task: Task) -> bool:
+        if Flags.tasks.get_value() == "1" and task.get_percent() > 99:
+            return True
+        if Flags.tasks.get_value() == "2" and task.get_percent() > 70:
+            return True
+        return False
+
+    def remove_empty_quests(self):
+        for c in self.game.clusters.values():
+            if c.key not in self.expanded:
+                continue
+            for q in c.get_quests():
+                if q.key not in self.expanded:
+                    continue
+                visible, _ = self.count_visible_hidden_tasks(q)
+                if visible == 0:
+                    self.expanded.remove(q.key)
+
     def reload_sentences(self):
         self.__update_max_title()
         self.items = []
-
+        self.remove_empty_quests()
         filtered, _ = self.filter_by_search()
         matcher = SearchAsc(self.search_text)
 
-        hide = not self.app.get_show_hidden() and not Flags.admin
+        hide = Flags.quests.get_value() == "0"
 
         clusters = [self.game.clusters[key] for key in self.game.clusters.keys() if key in filtered]
         if hide:
@@ -376,14 +351,23 @@ class TaskTree:
                 focus_color = quest_focus_color if self.selected_item == q.get_key() else ""
                 q.sentence = self.__str_quest(len(tasks) > 0, focus_color, q, lig)
 
-                # self.items.append(Entry(q, sentence))
+                full_task_size = len(tasks)
+                tasks = [t for t in tasks if not self.is_hide_tasks(t)]
+                filtered_tasks_size = len(tasks)
+                has_hidden_tasks = full_task_size != filtered_tasks_size
+
                 self.__try_add(filtered, matcher, q)
                 if q.key in self.expanded:
                     for t in tasks:
+                        if has_hidden_tasks:
+                            ligq = "┆ " if t != tasks[-1] else "╰ "
+                        else:
+                            ligq = "├ " if t != tasks[-1] else "╰ "
                         ligc = "│" if q != quests[-1] else " "
-                        ligq = "├ " if t != tasks[-1] else "╰ "
                         focus_color: str = quest_focus_color if self.selected_item == t.get_key() else ""
                         t.sentence: Text = self.__str_task(focus_color, t, ligc, ligq, q.is_reachable()) # type: ignore
+                        # if self.is_hide_tasks(t):
+                        #     continue
                         self.__try_add(filtered, matcher, t)
         # verifying if it has any selected item
         if self.items:
@@ -518,9 +502,16 @@ class TaskTree:
                 index -= 1
             self.set_selected_by_index(index)
 
+    def is_admin_mode(self) -> bool:
+        return Flags.quests.get_value() == "2"
+
     def unfold(self, obj: TreeItem) -> bool:
-        if isinstance(obj, Quest) and not obj.is_reachable() and not Flags.admin:
+        if isinstance(obj, Quest) and not obj.is_reachable() and not self.is_admin_mode():
             return False
+        if isinstance(obj, Quest):
+            visible, _ = self.count_visible_hidden_tasks(obj)
+            if visible == 0:
+                return False
         if isinstance(obj, Quest) or isinstance(obj, Cluster):
             if obj.key not in self.expanded:
                 self.expanded.append(obj.key)
@@ -531,6 +522,16 @@ class TaskTree:
                 return True
         return False
 
+    def count_visible_hidden_tasks(self, quest: Quest) -> tuple[int, int]:
+        visible = 0
+        hidden = 0
+        for t in quest.get_tasks():
+            if not self.is_hide_tasks(t):
+                visible += 1
+            else:
+                hidden += 1
+        return visible, hidden
+
     def fold(self, obj: TreeItem) -> bool:
         if isinstance(obj, Quest) or isinstance(obj, Cluster):
             if obj.key in self.expanded:
