@@ -31,6 +31,7 @@ from tko.util.raw_terminal import RawTerminal
 from tko.settings.repository import Repository
 from tko.logger.log_item_exec import LogItemExec
 from tko.logger.log_item_move import LogItemMove
+from tko.util.symbols import symbols
 
 
 class SeqMode(enum.Enum):
@@ -389,7 +390,7 @@ class Tester:
         cmds: list[Text] = []
 
         text = f"{GuiActions.config} [{GuiKeys.palette}]"
-        cmds.append(self.borders.border("C", f"{GuiActions.move} [{GuiKeys.up}{GuiKeys.left}{GuiKeys.down}{GuiKeys.right}]"))
+        cmds.append(self.borders.border("C", f"Mover  [setas]"))
         cmds.append(self.borders.border("C", text))
         cmds.append(self.borders.border("G", f"{GuiActions.evaluate_tester} [{symbols.newline.text}]"))
         cmds.append(self.borders.border("G", f"{GuiActions.execute_tester} [{GuiKeys.execute_tester}]"))
@@ -477,7 +478,7 @@ class Tester:
                     try:
                         self.wdir.get_solver().prepare_exec()
                     except CompileError as e:
-                        self.fman.add_input(Floating(self.settings, "v>").error().put_text(e.message))
+                        self.fman.add_input(Floating(self.settings, "v>").set_error().put_text(e.message))
                         self.mode = SeqMode.finished
                     Fmt.clear()
                     self.draw_top_bar()
@@ -501,11 +502,16 @@ class Tester:
                 continue
 
             if self.fman.has_floating():
-                key = self.fman.get_input()
-            else:
-                key = Fmt.getch()
+                self.fman.draw()
 
-            fn_exec = self.process_key(key)
+            # o input tem que ser depois do draw para mostrar o floating
+            value = InputManager.get_and_remap_keys(scr, self.app)
+            
+            if self.fman.has_floating():
+                # if consumed, value becomes -1
+                value = self.fman.process_input(value)
+
+            fn_exec = self.process_key(value)
             if fn_exec is not None:
                 return fn_exec
         return None
@@ -554,7 +560,7 @@ class Tester:
         if self.mode == SeqMode.finished:
             self.mode = SeqMode.select
         if self.locked_index:
-            self.fman.add_input(Floating(self.settings, "v>").warning().put_text("←\nAtividade travada\nAperte {} para destravar".format(GuiKeys.lock)))
+            self.fman.add_input(Floating(self.settings, "v>").set_warning().put_text("←\nAtividade travada\nAperte {} para destravar".format(GuiKeys.lock)))
             return
         if not self.wdir.get_solver().has_compile_error():
             self.focused_index = max(0, self.focused_index - 1)
@@ -568,7 +574,7 @@ class Tester:
         if self.mode == SeqMode.finished:
             self.mode = SeqMode.select
         if self.locked_index:
-            self.fman.add_input(Floating(self.settings, "v>").warning().put_text("→\nAtividade travada\nAperte {} para destravar".format(GuiKeys.lock)))
+            self.fman.add_input(Floating(self.settings, "v>").set_warning().put_text("→\nAtividade travada\nAperte {} para destravar".format(GuiKeys.lock)))
             return
         if not self.wdir.get_solver().has_compile_error():
             self.focused_index = min(len(self.wdir.get_unit_list()) - 1, self.focused_index + 1)
@@ -587,7 +593,7 @@ class Tester:
     def change_main(self):
         if len(self.get_solver_names()) == 1:
             self.fman.add_input(
-                Floating(self.settings, "v>").warning()
+                Floating(self.settings, "v>").set_warning()
                 .put_text("Seu projeto só tem um arquivo de solução.")
                 .put_text("Essa funcionalidade troca qual dos arquivos")
                 .put_text("de solução será o principal.")
@@ -628,13 +634,13 @@ class Tester:
                 self.locked_index = False
             else:
                 self.set_exit()
-        elif key == self.settings.app.get_key_left() or key == ord(GuiKeys.left) or key == ord(GuiKeys.left2):
+        elif key == curses.KEY_LEFT:
             self.go_left()
-        elif key == self.settings.app.get_key_right() or key == ord(GuiKeys.right) or key == ord(GuiKeys.right2):
+        elif key == curses.KEY_RIGHT:
             self.go_right()
-        elif key == self.settings.app.get_key_down() or key == ord(GuiKeys.down) or key == ord(GuiKeys.down2):
+        elif key == curses.KEY_DOWN:
             self.go_down()
-        elif key == self.settings.app.get_key_up() or key == ord(GuiKeys.up) or key == ord(GuiKeys.up2):
+        elif key == curses.KEY_UP:
             self.go_up()
         elif key == ord(GuiKeys.toggle_main):
             self.change_main()
@@ -643,31 +649,31 @@ class Tester:
         elif key == ord(GuiKeys.evaluate):
             self.run_test_mode()
         elif key == ord(GuiKeys.lock):
-            self.fman.add_input(Floating(self.settings, "v>").warning().put_text("Função de travamento {}".format("ligada" if not self.locked_index else "desligada")))
+            self.fman.add_input(Floating(self.settings, "v>").set_warning().put_text("Função de travamento {}".format("ligada" if not self.locked_index else "desligada")))
             self.lock_unit()
         elif key == ord(GuiKeys.edit):
             if self.opener is not None:
                 self.opener.load_folders_and_open()
         elif key == ord(GuiKeys.limite):
             self.change_limit()
-            self.fman.add_input(Floating(self.settings, "v>").warning().put_text("Limite de execução alterado para {}".format(self.get_time_limit_symbol())))
+            self.fman.add_input(Floating(self.settings, "v>").set_warning().put_text("Limite de execução alterado para {}".format(self.get_time_limit_symbol())))
             self.settings.save_settings()
         elif key == ord(GuiKeys.diff):
             self.settings.app.toggle_diff()
-            self.fman.add_input(Floating(self.settings, "v>").warning().put_text("Modo de Diff alterado para {}".format(self.settings.app.get_diff_mode().value)))
+            self.fman.add_input(Floating(self.settings, "v>").set_warning().put_text("Modo de Diff alterado para {}".format(self.settings.app.get_diff_mode().value)))
             self.settings.save_settings()
         elif key == ord(GuiKeys.borders):
             self.settings.app.toggle_borders()
-            self.fman.add_input(Floating(self.settings, "v>").warning().put_text("Modo de Bordas alterado para {}".format("ligado" if self.settings.app.get_use_borders() else "desligado")))
+            self.fman.add_input(Floating(self.settings, "v>").set_warning().put_text("Modo de Bordas alterado para {}".format("ligado" if self.settings.app.get_use_borders() else "desligado")))
             self.settings.save_settings()
         elif key == ord(GuiKeys.images):
             self.settings.app.toggle_images()
-            self.fman.add_input(Floating(self.settings, "v>").warning().put_text("Modo de Imagens alterado para {}".format("ligado" if self.settings.app.get_use_images() else "desligado")))
+            self.fman.add_input(Floating(self.settings, "v>").set_warning().put_text("Modo de Imagens alterado para {}".format("ligado" if self.settings.app.get_use_images() else "desligado")))
             self.settings.save_settings()
         elif key == ord(GuiKeys.palette):
             self.command_pallete()
         elif key != -1 and key != curses.KEY_RESIZE:
-            self.fman.add_input( Floating(self.settings, "v>").error().put_text(f"Tecla char:{chr(key)}, code:{key}, não reconhecida") )
+            self.fman.add_input( Floating(self.settings, "v>").set_error().put_text(f"Tecla char:{chr(key)}, code:{key}, não reconhecida") )
         return None
 
     def command_pallete(self):
@@ -725,7 +731,7 @@ class Tester:
         )
 
         self.fman.add_input(
-            FloatingInput(self.settings, "v").set_text_ljust()
+            FloatingInput(self.settings, "").set_text_ljust()
                       .set_header(" Selecione uma ação da lista ")
                       .set_options(options)
                       .set_exit_on_enter(False)
