@@ -8,6 +8,7 @@ from tko.util.text import Text
 from tko.logger.logger import Logger
 import yaml # type: ignore
 from tko.settings.rep_paths import RepPaths
+from icecream import ic
 
 def remove_git_merge_tags(lines: list[str]) -> list[str]:
     # remove lines with <<<<<<<, =======, >>>>>>>>
@@ -17,9 +18,10 @@ def remove_git_merge_tags(lines: list[str]) -> list[str]:
             continue
         filtered_lines.append(line)
     return filtered_lines
-class Repository:
 
 
+class Repository:
+
     def __init__(self, folder: str):
         rep_folder: str = folder
         recursive_folder = RepPaths.rec_search_for_repo(folder)
@@ -47,7 +49,7 @@ class Repository:
             self.load_config()
         database_folder = os.path.join(self.paths.root_folder, self.get_database_folder())
         cache_or_index = self.load_index_or_cache()
-        self.game.parse_file_and_folder(cache_or_index, database_folder, self.get_lang())
+        self.game.parse_file_and_folder(cache_or_index, database_folder, self.get_lang(), self.get_filter_view())
         self.__load_tasks_from_rep_into_game()
         return self
     
@@ -119,6 +121,7 @@ class Repository:
     __lang = "lang"
     __selected = "index"
     __database = "database"
+    __filter = "filter"
 
     defaults: dict[str, Any] = {
         __version: __actual_version,
@@ -128,9 +131,16 @@ class Repository:
         __tasks: {},
         __flags: {},
         __lang: "",
-        __selected: ""
+        __selected: "",
+        __filter: []
     }
 
+    def get_filter_view(self) -> list[str]:
+        return self.__get(Repository.__filter)
+    
+    def set_filter_view(self, value: list[str]):
+        self.__set(Repository.__filter, value)
+
     def get_database_folder(self) -> str:
         return self.__get(Repository.__database)
 
