@@ -1,5 +1,4 @@
 import subprocess
-from typing import Tuple, Optional
 import os
 from subprocess import PIPE
 
@@ -8,12 +7,17 @@ class Runner:
         pass
 
     @staticmethod
-    def subprocess_run(cmd: str, input_data: str = "", timeout:Optional[float] = None, folder: str | None = None) -> Tuple[int, str, str]:
+    def subprocess_run(cmd: str, input_data: str = "", timeout: None | float = None, folder: str | None = None) -> tuple[int, str, str]:
         try:
-            answer = subprocess.run(cmd, cwd=folder, shell=True, input=input_data, stdout=PIPE, stderr=PIPE, text=True, timeout=timeout)
+            env = os.environ.copy()
+            env['NO_COLOR'] = '1'
+            env['FORCE_COLOR'] = '0'
+            answer = subprocess.run(cmd, cwd=folder, env=env, shell=True, input=input_data, stdout=PIPE, stderr=PIPE, text=True, timeout=timeout)
             err = ""
             if answer.returncode != 0:
+
                 err = answer.stderr + Runner.decode_code(answer.returncode)
+                # err += "\n" + cmd
             # if running on windows
             if os.name == "nt":
                 return answer.returncode, answer.stdout.encode("cp1252").decode("utf-8"), err
@@ -39,18 +43,3 @@ class Runner:
         if code == 134:
             return "fail: runtime exception"
         return "fail: execution error code " + str(code)
-
-# class Runner:
-
-#     def __init__(self):
-#         pass
-
-#     @staticmethod
-#     def subprocess_run(cmd_list: List[str], input_data: str = "") -> Tuple[int, Any, Any]:
-#         try:
-#             p = subprocess.Popen(cmd_list, stdout=PIPE, stdin=PIPE, stderr=PIPE, universal_newlines=True)
-#             stdout, stderr = p.communicate(input=input_data)
-#             return p.returncode, stdout, stderr
-#         except FileNotFoundError:
-#             print("\n\nCommand not found: " + " ".join(cmd_list))
-#             exit(1)
